% Test code by Ann B. Lee, June 2006
% Last modified: ABL 3/4/07, 4/5/07, 1/25/08
% CALLS: Run_JTree (calls: Build_Jtree (calls:newJacobi), JTree_Basis)
%
% Remark: This is a simplified example where you feed in 
% the level of the tree (default: level=dim-1)

%-------------------------------------------------------------
% GENERATE TEST DATA SET (see AOAS paper, Example 1 in Sec.4.1)
%-------------------------------------------------------------
N=1000;
dim=10; % N is total number of obs
sigma = 1; 
seed = 88; rand('seed',seed);

s1_2=290; s2_2=300; c1=-0.3; c2=0.925;
u1 = sqrt(s1_2)*randn(N,1);
u2 = sqrt(s2_2)*randn(N,1); 
u3 = c1*u1 + c2*u2; s3_2=c1^2*s1_2+c2^2*s2_2;

Xraw = [u1, u1, u1, u1,   u2, u2, u2, u2,   u3, u3];
X = Xraw + sigma * randn(N,dim); % Generate data set

%-------------------------------------------------------------
% TREELET DECOMPOSITION
%-------------------------------------------------------------
k=1;
maxlev=dim-k;
[Z, Z_pos,T,PCidx,all_nodes,basis,sums,difs]= Run_JTree(X,maxlev);

% DENDROGRAM
Zmod=Z; %dendrogram(Zmod);
Zmod(:,3)=(1:size(Z,1)); figure, dendrogram(Zmod);
title('tree structure'), ylabel('Level, L') 
 
% FULL TREELET DECOMPOSITION (default)
k=1;  % k = number of clusters
disp('Compute full treelet decomposition');
maxlev=dim-k;

[Z, Z_pos,T,PCidx,all_nodes,basis,sums,difs,theta]= Run_JTree(X,maxlev);
figure, imagesc(basis), colormap gray, title('Full decomposition, level=dim-1 (basis vectors, row-wise)');
%basis, theta*180/pi

%---------------------------------------
% DECOMPOSITION AT LEVEL L=dim-k (optional)
% where k has been determined by cross-validation
% (see for example implementation in "JRSS_level.m")
%----------------------------------------
k=3; maxlev=dim-k; % example in paper
disp(sprintf('Optional: Decomposition at level dim-k where k=%d',k));
[basis, sums, difs] = JTree_Basis(Z_pos,T,PCidx,maxlev,all_nodes);

disp('Sort basis vectors according to decreasing energy'); % optional
[avE, order, score]=Calc_Energy(X,basis,k);
TT=basis(order,:);
figure, imagesc(TT), colormap gray, title('Alternative decomposition, level=dim-3 (basis vectors, row-wise)');

disp('Plot maximum energy treelets');
figure, plot(1:10,TT(1,:),'bo-',1:10,TT(2,:),'g*--',1:10,TT(3,:),'rd-.',...
'linewidth',2,'markersize',10);
h=legend('T1','T2','T3'); set(h,'fontsize',16);
xlabel('coordinate','fontsize',16); ylabel('loading','fontsize',16);
title('Maximum Energy Treelets','fontsize',16);

